==============
format-pipfile
==============

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis| |appveyor| |requires|
        | |coveralls| |codecov| |scrutinizer-coverage| |codeclimate-coverage|
        | |scrutinizer| |code-intelligence| |codacy| |codeclimate|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|

.. |docs|
    image:: https://readthedocs.org/projects/format-pipfile/badge/?version=latest
    :target: https://format-pipfile.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |travis|
    image:: https://travis-ci.com/demosdemon/format-pipfile.svg?branch=master
    :target: https://travis-ci.com/demosdemon/format-pipfile
    :alt: Travis-CI Build Status

.. |appveyor|
    image:: https://ci.appveyor.com/api/projects/status/qt6g7115uyfm4lrs/branch/master?svg=true
    :target: https://ci.appveyor.com/project/demosdemon/format-pipfile/branch/master
    :alt: AppVeyor Build Status

.. |requires|
    image:: https://requires.io/github/demosdemon/format-pipfile/requirements.svg?branch=master
    :target: https://requires.io/github/demosdemon/format-pipfile/requirements/?branch=master
    :alt: Requirements Status

.. |coveralls|
    image:: https://coveralls.io/repos/github/demosdemon/format-pipfile/badge.svg?branch=master
    :target: https://coveralls.io/github/demosdemon/format-pipfile?branch=master
    :alt: Coverage Status

.. |codecov|
    image:: https://codecov.io/gh/demosdemon/format-pipfile/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/demosdemon/format-pipfile
    :alt: Coverage Status

.. |scrutinizer|
    image:: https://scrutinizer-ci.com/g/demosdemon/format-pipfile/badges/quality-score.png?b=master
    :target: https://scrutinizer-ci.com/g/demosdemon/format-pipfile/?branch=master
    :alt: Scrutinizer Code Quality

.. |scrutinizer-coverage|
    image:: https://scrutinizer-ci.com/g/demosdemon/format-pipfile/badges/coverage.png?b=master
    :target: https://scrutinizer-ci.com/g/demosdemon/format-pipfile/?branch=master
    :alt: Code Coverage

.. |code-intelligence|
    image:: https://scrutinizer-ci.com/g/demosdemon/format-pipfile/badges/code-intelligence.svg?b=master
    :target: https://scrutinizer-ci.com/code-intelligence
    :alt: Code Intelligence Status

.. |codacy|
    image:: https://api.codacy.com/project/badge/Grade/e4580ab6f2b14460a3d9d6ec0a9504ee
    :target: https://www.codacy.com/app/demosdemon/format-pipfile?utm_source=github.com&utm_medium=referral&utm_content=demosdemon/format-pipfile&utm_campaign=Badge_Grade
    :alt: Code Quality

.. |codeclimate|
    image:: https://api.codeclimate.com/v1/badges/87bdc343b0192b56c762/maintainability
    :target: https://codeclimate.com/github/demosdemon/format-pipfile/maintainability
    :alt: Code Climate Maintainability

.. |codeclimate-coverage|
    image:: https://api.codeclimate.com/v1/badges/87bdc343b0192b56c762/test_coverage
    :target: https://codeclimate.com/github/demosdemon/format-pipfile/test_coverage
    :alt: Code Climate Test Coverage

.. |version|
    image:: https://img.shields.io/pypi/v/format-pipfile.svg
    :target: https://pypi.org/project/format-pipfile
    :alt: PyPI Package Latest Release

.. |wheel|
    image:: https://img.shields.io/pypi/wheel/format-pipfile.svg
    :target: https://pypi.org/project/format-pipfile
    :alt: PyPI Wheel

.. |supported-versions|
    image:: https://img.shields.io/pypi/pyversions/format-pipfile.svg
    :target: https://pypi.org/project/format-pipfile
    :alt: Supported Python Versions

.. |supported-implementations|
    image:: https://img.shields.io/pypi/implementation/format-pipfile.svg
    :target: https://pypi.org/project/format-pipfile
    :alt: Python Implementation

.. |commits-since|
    image:: https://img.shields.io/github/commits-since/demosdemon/format-pipfile/v0.0.6.svg
    :target: https://github.com/demosdemon/format-pipfile/compare/v0.0.6...master
    :alt: Commits since latest release

.. end-badges

A Python utility to format TOML Pipfiles with some very opinionated rules.
